@@ -18,26 +18,28 @@
 #' sims <- runif_in_tetrahedron(100, vs[, 1], vs[, 2], vs[, 3], vs[, 4])
 #' points3d(sims)}
 runif_in_tetrahedron <- function(n, v1, v2, v3, v4){
-  out <- matrix(NA_real_, nrow=n, ncol=3L)
-  c <- cbind(matrix(runif(n*3), nrow=n, ncol=3L), NA_real_)
+  out <- matrix(NA_real_, nrow = n, ncol = 3L)
+  c <- matrix(runif(n*3), nrow = n, ncol = 3L)
   for(j in 1L:n){
-    if( 1 < c[j,1L] + c[j,2L] ){
-      c[j,1L] <- 1 - c[j,1L]
-      c[j,2L] <- 1 - c[j,2L]
+    c1 <- c[j, 1L]
+    c2 <- c[j, 2L]
+    c3 <- c[j, 3L]
+    if( 1 < c1 + c2 ) {
+      c1 <- 1 - c1
+      c2 <- 1 - c2
     }
-    if( 1 < c[j,2L] + c[j,3L] ){
-      t <- c[j,3L]
-      c[j,3L] <- 1 - c[j,1L] - c[j,2L]
-      c[j,2L] <- 1 - t
+    if( 1 < c2 + c3 ) {
+      t <- c3
+      c3 <- 1 - c1 - c2
+      c2 <- 1 - t
+    } else if( 1 < (s <- c1 + c2 + c3) ) {
+      t <- c3
+      c3 <- s - 1
+      c1 <- 1 - c2 - t
     }
-    else if( 1 < (s <- sum(c[j,1L:3L])) ){
-      t <- c[j,3L]
-      c[j,3L] <- s - 1
-      c[j,1L] <- 1 - c[j,2L] - t
-    }
-    c[j,4L] = 1 - sum(c[j,1L:3L])
+    c4 <- 1 - (c1 + c2 + c3)
 
-    out[j,] <- c[j,1L] * v1 + c[j,2L] * v2 + c[j,3L] * v3 + c[j,4L] * v4
+    out[j, ] <- c1 * v1 + c2 * v2 + c3 * v3 + c4 * v4
   }
   out
 }
